######
opinel
######

.. image:: https://travis-ci.org/nccgroup/opinel.svg?branch=master
        :target: https://travis-ci.org/nccgroup/opinel
.. image:: https://coveralls.io/repos/github/nccgroup/opinel/badge.svg?branch=master
        :target: https://coveralls.io/github/nccgroup/opinel?branch=master      
.. image:: https://badge.fury.io/py/opinel.svg
        :target: https://badge.fury.io/py/opinel
        :align: right

************
Introduction
************

opinel is the Python package used by `Scout2`_ and `AWS-Recipes`_.

************
Installation
************

Install via `pip`_:

::

    $ pip install opinel

Install from source:

::

    $ git clone https://github.com/nccgroup/opinel
    $ cd opinel
    $ python setup.py install

.. _Scout2: https://github.com/nccgroup/Scout2
.. _AWS-Recipes: https://github.com/nccgroup/AWS-Recipes
.. _pip: https://pip.pypa.io/en/stable/index.html
